@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2023 Yoran Heling
+  Copyright (c) Yorhel
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -34,7 +34,7 @@
 #include <locale.h>
 #endif
 
-int uic_theme;
+int uic_theme = 0;
 int winrows, wincols;
 int subwinr, subwinc;
 static char thou_sep;
